/*
 * $Id$
 *
 * Copyright (c) 2021 NetApp, Inc.
 * All rights reserved.
 */
package com.netapp.df.uba.server.common.elastic

import com.netapp.df.uba.server.common.elastic.model.{EsClusterInfo, EsClusterInfoJsonFormats}
import com.netapp.df.uba.server.common.misc.log.LogTrait
import com.netapp.df.uba.server.common.misc.rest.RestUtils
import org.apache.http.HttpHost
import org.apache.http.client.methods.HttpGet
import spray.json._

import scala.util.{Failure, Success, Try}

/**
  * Class that handles the call to service-tenants to get information about ES Clusters
  * serviceTenantsUrl: "https://cs-service-tenants.cloudsecure.svc:8080"
  */
class EsClustersClient(serviceTenantsUrl: String) extends RestUtils with LogTrait {

  def retrieveEsCluster(esClusterId: String): Try[EsClusterInfo] = Try {

    val httpHost = HttpHost.create(serviceTenantsUrl)

    val httpResponseBodyTry: Try[String] = execute(
      tenantIdOption = None, // eclusters API uses tenant_admin privilege
      HttpGet.METHOD_NAME,
      uri = s"/rest/v1/esclusters/$esClusterId",
      httpHost
    )
    // Parse the response into a list of ES clusters
    httpResponseBodyTry match {
      case Success(httpResponseBody) =>

        // Parse the response into a list of ES clusters
        implicit val esClusterInfoJsonFormats: EsClusterInfoJsonFormats = new EsClusterInfoJsonFormats
        import esClusterInfoJsonFormats._

        httpResponseBody
          .parseJson
          .convertTo[EsClusterInfo]

      case Failure(ex) =>
        logger.error(s"Failed to retrieve elastic cluster $esClusterId from tenants service. Reason: ${ex.getMessage}")
        throw ex
    }
  }

  def retrieveEsClusters(): Try[List[EsClusterInfo]] = Try {

    val httpHost = HttpHost.create(serviceTenantsUrl)

    val httpResponseBodyTry: Try[String] = execute(
      tenantIdOption = None, // eclusters API uses tenant_admin privilege
      HttpGet.METHOD_NAME,
      uri = "/rest/v1/esclusters",
      httpHost
    )
    // Parse the response into a list of ES clusters
    httpResponseBodyTry match {
      case Success(httpResponseBody) =>

        // Parse the response into a list of ES clusters
        implicit val esClusterInfoJsonFormats: EsClusterInfoJsonFormats = new EsClusterInfoJsonFormats
        import esClusterInfoJsonFormats._

        httpResponseBody
          .parseJson
          .convertTo[List[EsClusterInfo]]

      case Failure(ex) =>
        logger.error(s"Failed to retrieve elastic clusters from tenants service. Reason: ${ex.getMessage}")
        throw ex
    }
  }
}