/*
 * $Id$
 *
 *  Copyright (c) 2019 NetApp, Inc.
 *  All rights reserved.
 */

package com.netapp.df.uba.server.common.elastic.utils

/**
  * A bunch of constants used in different parts of the query handlers
  *
  * Constants are related to different topics
  *   - Common field names
  *   - Query defaults
  *   - Aggregation related
  */

import scala.concurrent.duration._

object FieldConstants {

  // Commonly used field names
  val IdFieldName = "id"
  val EntityIdFieldName = "entityId"
  val TenantIdFieldName = "tenantId"
  val UserIdFieldName = "userId"
  val DatasourceIdFieldName = "datasourceId"
  val VolumeIdFieldName = "dataVolumeId"
  val CommunityIdFieldName = "communityId"
  val ActivityCount = "activityCount"
  val ActivityEventTimestampField = "eventTimestamp"
  val ExtensionFieldName = "objectExtension"
  val EventTypeFieldName = "eventType"
  val IsTemporary = "isTemporary"
  val JustCreatedEntity = "justCreatedEntityEvent"
  val IsHomeDirectoryEvent = "isHomeDirectoryEvent"
  val AlertTrigger = "alertTrigger"
  val AdAlgorithm = "adAlgorithm"

  // Commonly used in cross-index queries
  val UserName = "userName"
  val EntityPath = "entityPath"
  val CommunityName = "communityName"
  val CommunitiesCount = "communitiesCount"
  val AlertSeverity = "alertSeverity"
  val DeviceName = "deviceName"
  val LastEntityAccessedTime = "lastEntityAccessedTime"
  val VolumeName = "volumeName"
  val TempEntitiesNoiseFilter = "tempEntitiesNoiseFilter"
  val NewlyCreatedEntitiesNoiseFilter = "newlyCreatedEntitiesNoiseFilter"
  val Domain = "domain"
  val LimitationStatus = "limitationStatus"

  //Protocol field
  val ProtocolName = "protocol"

  // Commonly used in queries
  val DefaultSortField: String = "id"
  val DefaultField = "id"
  val MatchAll = "*"
  val ShowVersion = true
  val KeyWord = "keyword"
  val DOT = "."
  val OtherField = "others"
  val Other = "Other"

  // Miscellaneous constants
  val EmptyString = ""
  val ObjectTypeString = "object type"
  val SourceObjectTypeString = "source object type"

  //Used for sort missing parameter
  val MissingParam = "_last"

  /*Reserved characters for Query String query. Original regex: ([-+=><!(){}\[\]^"~?:/\s])
  * Few special characters need to be escaped within character class itself, which includes:
  * [ ] " \ / whitespace aka \s
  * Reference:
  * https://www.elastic.co/guide/en/elasticsearch/reference/6.3/query-dsl-query-string-query.html#_reserved_characters
  * Note: Removed literal backslash (aka \) and literal wildcard (aka *) from this set, as they get escaped from UI
  * itself due to their special nature.
   */
  val ReservedCharsQueryStr = "([-+=><!(){}\\[\\]^\"~?:\\/\\s])"

  //Unknown or missing object
  val UNKNOWN = "UNKNOWN/MISSING"

  val MaxSearchIntervalDuration: FiniteDuration = 32.days

  //This should be in sync with curator shard allocation config for cold nodes. Any changes in cold search interval
  //should be done in both curator config and here.
  val ColdSearchDuration: FiniteDuration = 90.days
}

// A set of constants used as error targets
object ErrorTargetConstants {
  val EntitySearchTarget = "Entity search API"
  val AlertSearchTarget = "Alert search API"
  val AlertUpdateTarget = "Alert update API"
  val UserSearchTarget = "User search API"
  val TimeseriesTarget = "Timeseries API"
  val SummariesTarget = "Summaries API"
}


