/*
 * $Id$
 *
 * Copyright (c) 2018 NetApp, Inc.
 * All rights reserved.
 */
package com.netapp.df.uba.server.common.flink.actor

import akka.actor.{Actor, ActorLogging, ActorRef, Props}
import akka.event.LoggingReceive
import com.netapp.df.uba.server.common.flink.cluster.FlinkApiClusterHandler
import com.netapp.df.uba.server.common.flink.settings.FlinkSettings
import com.netapp.df.uba.server.common.misc.model._

/**
  * FlinkInfraChecker is the actor that is responsible for checking connectivity to flink server
  */
object FlinkInfraChecker {
  def props(flinkSettings: FlinkSettings,
            requestorRef: ActorRef): Props = Props(new FlinkInfraChecker(flinkSettings, requestorRef))

  final val ContextFlinkInfraCheck: String = "flinkInfraCheck"
}

class FlinkInfraChecker(flinkSettings: FlinkSettings, requestorRef: ActorRef) extends Actor with ActorLogging {

  import FlinkInfraChecker._

  override def preStart(): Unit = {
    // Send a self message
    self ! CheckInfra
  }

  // Receive case for flink check
  override def receive: Receive = LoggingReceive {

    // Message to check for flink clusters
    case CheckInfra =>
      checkFlinkConnection() match {
        case scala.util.Success(_) =>
          log.info(s"Flink cluster connection check to ${flinkSettings.cluster.host} succeeded.")

          // Send action done to parent
          requestorRef ! ActionSucceeded(ContextFlinkInfraCheck)

        // Kafka broker check failed
        case scala.util.Failure(ex) =>
          val errorMessage = s"Flink cluster connection check failed with message: ${ex.getMessage}"
          log.error(errorMessage)

          // Send action done to parent
          requestorRef ! ActionFailed(ContextFlinkInfraCheck, Error(ErrorCode.ConnectionNotEstablished, errorMessage, flinkSettings.cluster.host))
      }

    case somethingElse =>
      log.warning(s"${this.getClass.getSimpleName} actor received a message that is not handled: " + somethingElse)
  }

  protected def checkFlinkConnection(): scala.util.Try[Boolean] = {
    val flinkUtils = FlinkApiClusterHandler(flinkSettings.cluster)
    flinkUtils.checkFlinkConnection()
  }
}
