/*
 * $Id$
 *
 * Copyright (c) 2018 NetApp, Inc.
 * All rights reserved.
 */
package com.netapp.df.uba.server.common.kafka

import java.util

import org.apache.kafka.clients.producer.ProducerRecord
import org.apache.kafka.common.errors.RecordTooLargeException
import org.apache.kafka.streams.errors.ProductionExceptionHandler
import org.apache.kafka.streams.errors.ProductionExceptionHandler.ProductionExceptionHandlerResponse
import org.slf4j.LoggerFactory

/**
  * A kafka production exception handler that ignores the issue of record being too large
  */
class IgnoreRecordTooLargeException extends ProductionExceptionHandler {

  private val log = LoggerFactory.getLogger(classOf[IgnoreRecordTooLargeException])

  override def handle(record: ProducerRecord[Array[Byte], Array[Byte]], exception: Exception): ProductionExceptionHandler.ProductionExceptionHandlerResponse =
    if (exception.isInstanceOf[RecordTooLargeException]) {
      log.warn("RecordTooLargeException exception caught during stream processing of " + "topic: {}, partition: {}. Continuing stream processing.", record.topic, record.partition, exception)
      ProductionExceptionHandlerResponse.CONTINUE
    }
    else {
      log.error("Exception caught during stream processing of " + "topic: {}, partition: {}. Marking stream processing as failed.", record.topic, record.partition, exception)
      ProductionExceptionHandlerResponse.FAIL
    }

  override def configure(configs: util.Map[String, _]): Unit = {}
}