/*
 * $Id$
 *
 * Copyright (c) 2018 NetApp, Inc.
 * All rights reserved.
 */
package com.netapp.df.uba.server.common.kafka

import com.netapp.df.uba.server.common.misc.utils.SettingUtils
import com.typesafe.config.Config
import scala.collection.JavaConverters._

/**
  * Contains settings related to kafka consumer.
  * Used mainly in flink jobs that read from kafka and sink to elastic
  */
object KafkaConsumerSettings {
  def apply(config: Config): KafkaConsumerSettings = {

    /*
     Load all the configurations in the block which is not group.id
     Gives flexibility in providing any of the consumer settings as required.
      */
    val consumerConfigMap: Map[String, String] = config.entrySet()
      .asScala
      .filterNot(item => item.getKey == "group.id")
      .map(item => item.getKey -> item.getValue.unwrapped().toString)
      .toMap

    KafkaConsumerSettings(
      SettingUtils.mandatoryConfigValue(config, "group.id"),
      consumerConfigMap
    )
  }
}

case class KafkaConsumerSettings(groupId: String,
                                 consumerConfig: Map[String, String])