/*
 * $Id$
 *
 * Copyright (c) 2018 NetApp, Inc.
 * All rights reserved.
 */
package com.netapp.df.uba.server.common.kafka

import com.netapp.df.uba.server.common.misc.utils.SettingUtils
import com.typesafe.config.Config
import scala.collection.JavaConverters._

/**
  * Contains settings related to kafka producer.
  * Used mainly in flink jobs that sink to kafka
  */
object KafkaProducerSettings {
  def apply(config: Config): KafkaProducerSettings = {

    /*
     Load all the configurations in the block which is not group.id
     Gives flexibility in providing any of the producer settings as required.
      */
    val producerConfigMap: Map[String, String] = config.entrySet()
      .asScala
      .filterNot(item => item.getKey == "client.id")
      .map(item => item.getKey -> item.getValue.unwrapped().toString)
      .toMap

    KafkaProducerSettings(
      SettingUtils.mandatoryConfigValue(config, "client.id"),
      producerConfigMap
    )
  }
}

case class KafkaProducerSettings(clientId: String,
                                 producerConfig: Map[String, String])