/*
 * $Id$
 *
 * Copyright (c) 2018 NetApp, Inc.
 * All rights reserved.
 */
package com.netapp.df.uba.server.common.misc.actor

import akka.actor.{Actor, ActorLogging, ActorRef, Props}
import akka.event.LoggingReceive
import com.netapp.df.uba.server.common.misc.model.{GetStateDetails, StateDetails}
import com.netapp.df.uba.server.common.misc.utils.{AppActorUser, ExecContextAndTimeOutImplicits, StateUtils}

/**
  * Request handling actor to get hold of the component state and return the information to the API handler
  */
object StateApiHandler {
  final val ActorName: String = "stateManager"
  final val ActorPath: String = s"/user/appManager/$ActorName"

  def props(componentName: String, stateManagerPath: String): Props = Props(new StateApiHandler(componentName, stateManagerPath))

  // Message sent to this actor to get the current connector state
  case object GetState
}

class StateApiHandler(componentName: String, stateManagerPath: String)
  extends Actor
    with ActorLogging
    with ExecContextAndTimeOutImplicits
    with AppActorUser {

  import StateApiHandler._
  import context._

  // Initially receive the request from the route handlers
  override def receive: Receive = LoggingReceive {
    case GetState =>
      // Set an overall receive timeout so that the actor is stopped on its own in case there is no response from the underlying application actors
      setReceiveTimeout(timeout.duration)

      // Send a message to StateManager to get hold of the connector state
      askDataFromActor(stateManagerPath, GetStateDetails)

      // Wait for responses from the underlying app
      context.become(appResponseReceive(sender()).orElse(timedOutReceive))
  }

  private def appResponseReceive(routeHandler: ActorRef): Receive = LoggingReceive {
    // Received response from state manager
    case stateDetails: StateDetails =>
      sendResponse(routeHandler, StateUtils.getComponentStateApi(stateDetails, componentName))
  }
}