/*
 * $Id$
 *
 * Copyright (c) 2018 NetApp, Inc.
 * All rights reserved.
 */
package com.netapp.df.uba.server.common.misc.api

import akka.actor.ActorSystem
import akka.http.scaladsl.server.{Directives, PathMatcher}
import akka.stream.ActorMaterializer

/**
  * Base trait for all routes. This mainly contains the basePath to be used by all other routes
  * as all other routes are anchored below this route.
  *
  * Micro service mainly follows the actor per request pattern to implement the APIs
  * where each request is sent to an actor whose life cycle is bound to the request, so it is started,
  * gets the request, does some processing and produces a complete or failed result back to the HTTP client.
  */
trait BaseRoute extends Directives {
  implicit val system: ActorSystem
  implicit val materializer: ActorMaterializer

  // Base API path under which all APIs are anchored
  protected val basePath: PathMatcher[Unit] = "rest" / "v1"
}
