package com.netapp.df.uba.server.common.misc.api

import akka.http.scaladsl.model.{StatusCode, StatusCodes}
import com.netapp.df.uba.server.common.misc.model.ErrorCode._

object ErrorUtils {

  /**
    * Utility method to covert error codes to status codes used as REST API HTTP status codes
    * All error codes used to complete an API request should have a case here.
    * Otherwise, will lead to scala.MatchError
    */
  def errorCodeToStatusCodes(errorCode: ErrorCode): StatusCode = errorCode match {
    case InternalError => StatusCodes.InternalServerError

    case InvalidCredentials => StatusCodes.Unauthorized

    case ConnectionNotEstablished |
         ServiceNotRunning |
         ServiceUnsupported |
         ServiceDisabled |
         ServiceFailed
            => StatusCodes.ServiceUnavailable

    case NotFound | ObjectNotDiscovered => StatusCodes.NotFound

    case BadRequest |
         InvalidAgentId |
         InvalidDatasourceId |
         InventoryRefreshFailure |
         UnsupportedDatasource |
         UnsupportedDatasourceVersion
            => StatusCodes.BadRequest

    case NoError => StatusCodes.OK
  }
}
