/*
 * $Id$
 *
 * Copyright (c) 2018 NetApp, Inc.
 * All rights reserved.
 */
package com.netapp.df.uba.server.common.misc.dbmodel

import com.netapp.df.uba.server.common.misc.dbmodel.AuditEventType.AuditEventType
import com.netapp.df.uba.server.common.misc.dbmodel.MetadataObjectType.MetadataObjectType

/**
  * Database model of the event object
  *
  * clientCoordinates:
  * geo-point data type can be in one of four formats:
  * 1. "location": {  (Geo-point expressed as an object, with lat and lon keys.)
  * "lat": 41.12,
  * "lon": -71.34
  * }
  * 2. "location": "41.12,-71.34"   (Geo-point expressed as a string with the format: "lat,lon")
  * 3. "location": "drm3btev3e86"  (Geo-point expressed as a geohash.)
  * 4. "location": [ -71.34, 41.12 ]  (Geo-point expressed as an array with the format: [ lon, lat])
  *
  * geoCoordinates above is using the string format i.e type (2) in the above list.
  * Reference: https://www.elastic.co/guide/en/elasticsearch/reference/current/geo-point.html
  */
case class AuditEventDb(tenantId: String,
                        id: String,
                        datasourceId: String,
                        eventTimestamp: Long,
                        eventType: AuditEventType,
                        objectType: MetadataObjectType,
                        canonicalPath: String,
                        displayPath: String,
                        entityName: String,
                        objectExtension: String,
                        originalCanonicalPath: Option[String],
                        originalDisplayPath: Option[String],
                        userDisplayName: String,
                        mountPath: Option[String],
                        clientIpAddress: String,
                        clientCoordinates: Option[String],
                        sizeBytes: Long,
                        dataVolumeId: String,
                        userId: String,
                        rawUserId: Option[String],
                        protocol: Option[ProtocolInfoDb],
                        entityId: String,
                        originalEntityId: Option[String],
                        justCreatedEntityEvent: Option[Boolean] = Some(false),
                        isTemporary: Option[Boolean] = Some(false),
                        isHomeDirectoryEvent: Option[Boolean] = Some(false)) {
  /**
    * @return True if the event is from a raw user
    */
  def isRaw: Boolean = {
    userDisplayName.equalsIgnoreCase(rawUserId.getOrElse(""))
  }

  /**
    * @return True if the event is from a real user
    */
  def isReal: Boolean = !isRaw
}