/*
 * $Id$
 *
 *  Copyright (c) 2018 NetApp, Inc.
 *  All rights reserved.
 */

package com.netapp.df.uba.server.common.misc.dbmodel

/**
  * Enumeration representing the Audit event types
  *
  * Added this object specific to Audit-Events,
  * since change in MetadataEventType may break the pipeline as it is being referred in other services.
  * NOTE: In future, we may have to make change in the entire pipe line to adapt for seamless upgrade. This class will be removed then.
  */
object AuditEventType extends Enumeration {
  type AuditEventType = Value

  val Create: AuditEventType = Value("create")
  val Read: AuditEventType = Value("read")
  val ReadMetadata: AuditEventType = Value("readMetadata")
  val Copy: AuditEventType = Value("copy")
  val Delete: AuditEventType = Value("delete")
  val Write: AuditEventType = Value("write")
  val WriteMetadata: AuditEventType = Value("writeMetadata")
  // ChangePermission, ChangeOwner, ChangeGroupOwnership are sub types for WriteMetadata from FPolicy
  val ChangePermission: AuditEventType = Value("changePermission")
  val ChangeOwner: AuditEventType = Value("changeOwner")
  val ChangeGroupOwnership: AuditEventType = Value("changeGroupOwnership")
  val Move: AuditEventType = Value("move")
  val Rename: AuditEventType = Value("rename")
  val OtherChange: AuditEventType = Value("otherChange")
  val FullRefresh: AuditEventType = Value("fullRefresh")
  val UnknownChange: AuditEventType = Value("unknownChange")

  def isEventTypePublic(auditEventType: AuditEventType): Boolean = {
    auditEventType match {
      case AuditEventType.Copy | AuditEventType.Move => false
      case _ => true
    }
  }
}