/*
 * $Id$
 *
 * Copyright (c) 2018 NetApp, Inc.
 * All rights reserved.
 */
package com.netapp.df.uba.server.common.misc.dbmodel

/**
  * Case class representing the database model of community object
  * tenantId: Tenant to which the community belongs to
  * id: Id of the community for cross reference
  * name: Name given to the community by the system for ease of reference
  * userIds: Set of users in the community identified by their ids
  * usersCount: Count of number of users in the community
  * entityIds: Set of entities in the community identified by their ids
  * entitiesCount: Count of number of entities in the community
  * userIdsHash: A hash of user ids in the community for ease of community resolution
  * firstReportedTimestamp: Indicates the timestamp the community was first seen
  * lastReportedTimestamp: Indicates the timestamp the community was last seen and updated by CD and CR
  */
case class CommunityDb(tenantId: String,
                       id: String,
                       name: String,
                       userIds: List[String],
                       usersCount: Long,
                       entityIds: List[String],
                       entitiesCount: Long,
                       userIdsHash: String,
                       firstReportedTimestamp: Long,
                       lastReportedTimestamp: Long,
                       mappingsCount: Option[Long] = None
                    ) extends ObjWithIdAndLastReported

/**
  * Class representing details of the presence of the combination of user and entity in a community
  * tenantId: Tenant to which the community belongs to
  * communityId: Id of the community to which this record belongs to
  * userId: Id of the user
  * entityId: Id of the entity
  * userJoiningTimestamp: Timestamp of when the user joined
  * entityJoiningTimestamp: Timestamp of when the entity joined
  * accessCount: Number of times the entity was accessed by the user in the last time window for which the CD ran
  * prior: Prior value which provides decay
  * runId: Run id of the algorithm
  * lastReportedTimestamp: Indicates the timestamp this mapping was last seen and updated by CD and CR
  */
case class CommunityMappingDb(tenantId: String,
                              communityId: String,
                              userId: String,
                              userJoiningTimestamp: Long,
                              entityId: String,
                              entityJoiningTimestamp: Long,
                              accessCount: Long,
                              prior: Double,
                              runId: Long,
                              lastReportedTimestamp: Long) extends ObjWithIdAndLastReported {
  def id: String = communityId
}