/*
 * $Id$
 *
 * Copyright (c) 2018 NetApp, Inc.
 * All rights reserved.
 */
package com.netapp.df.uba.server.common.misc.dbmodel

import com.netapp.df.uba.server.common.misc.utils.HexHashUtils

/**
  * Set of utility methods to get ids of objects
  */
object DocumentIds {

  /*
   Generic method for hash generation.
   Since the strings are concatenated and then a hash is generated currently,
   it is necessary that the strings are sorted before the hash is called.
    */
  def genericIdMethod(idComponents: String*): String = HexHashUtils.sha256Hex(idComponents.toList.sorted.mkString(":"))

  // Utility to get the document id of a user object
  def userDocumentId(tenantId: String, userId: String): String = genericIdMethod(tenantId, userId.toLowerCase)

  // Utility to get the document id of a entity object
  def entityDocumentId(tenantId: String, datasourceId: String, dataVolumeId: String, canonicalPath: String): String =
    genericIdMethod(tenantId, datasourceId, dataVolumeId, canonicalPath)

  // Utility to get the document id of a entity object
  def genEventId: String = java.util.UUID.randomUUID().toString

  // Utility to get the document id of a datasource object
  def realDatasourceDocumentId(tenantId: String, datasourceId: String): String = genericIdMethod(tenantId, datasourceId)

  def subDatasourceDocumentId(tenantId: String, datasourceId: String, name: String): String = genericIdMethod(tenantId, datasourceId, name)

  // Utility to get the document id of a data volume object
  def dataVolumeDocumentId(tenantId: String, datasourceId: String, dataVolumeId: String): String = genericIdMethod(tenantId, datasourceId, dataVolumeId)

  // Utility to get the document id of a user directory object
  def userDirectoryDocumentId(tenantId: String, datasourceId: String, userDirectoryId: String): String = genericIdMethod(tenantId, datasourceId, userDirectoryId)

  // Utility to get the document id of a share object
  def shareDocumentId(tenantId: String, datasourceId: String, shareId: String): String = genericIdMethod(tenantId, datasourceId, shareId)

  // Utility to get the document id of a export object
  def exportDocumentId(tenantId: String, datasourceId: String, exportId: String): String = genericIdMethod(tenantId, datasourceId, exportId)

  // Utility to get hash of users used in community objects
  def hashOfUsersOfCommunity(userIds: List[String]): String = genericIdMethod(userIds:_*)
}
