/*
 * $Id$
 *
 * Copyright (c) 2018 NetApp, Inc.
 * All rights reserved.
 */
package com.netapp.df.uba.server.common.misc.dbmodel

import com.netapp.df.uba.server.common.misc.utils.EnumerationUtils

/**
  * A marker trait for inventory DB model objects
  */
trait InventoryObjectDb extends ObjWithIdAndLastReported

/**
  * Type to distinguish type of datasource connectors
  */
object ConnectorType extends Enumeration {
  type ConnectorType = Value

  val DataType: ConnectorType = Value("data")
  val DataUsersType: ConnectorType = Value("dataAndUsers")
  val UserType: ConnectorType = Value("users")
  val InventoryOnlyType: ConnectorType = Value("inventoryOnly")
}

// Case sensitivity nature of the data volume
object CaseSensitiveNature extends Enumeration {
  type CaseSensitiveNature = Value

  val CaseSensitive: CaseSensitiveNature = Value("sensitive")
  val CaseInsensitive: CaseSensitiveNature = Value("insensitive")
}

// Type of the remote data volume. It can currently be either FileSystem or Bucket type.
object DataVolumeType extends Enumeration {
  type DataVolumeType = Value

  val FileSystem: DataVolumeType = Value("fileSystem")
  val Bucket: DataVolumeType = Value("bucket")
}

object DataVolumeState extends Enumeration {
  type DataVolumeState = Value

  val Online: DataVolumeState = Value("online")
  val Offline: DataVolumeState = Value("offline")
  val Unknown: DataVolumeState = Value("unknown")

  def withValue(fromApi: String): DataVolumeState =
    EnumerationUtils.getValidEnumValue[DataVolumeState](values, fromApi, Unknown) { strEnum => withName(strEnum) }
}

// An enumeration to indicate whether the users are defined locally or remotely from ONTAP in a different system
object UserDirectoryLocation extends Enumeration {
  type UserDirectoryLocation = Value

  val Local: UserDirectoryLocation = Value("local")
  val Remote: UserDirectoryLocation = Value("remote")
}

/**
  * Enumeration representing the type of export object
  */
object ExportObjectType extends Enumeration {
  type ExportObjectType = Value

  val Policy: ExportObjectType = Value("policy")
}
