/*
 * $Id$
 *
 * Copyright (c) 2018 NetApp, Inc.
 * All rights reserved.
 */
package com.netapp.df.uba.server.common.misc.dbmodel

import com.netapp.df.uba.server.common.misc.dbmodel.AuditEventType.AuditEventType

/**
  * Case class representing the database model of ops rate metrics
  * id: Identifier for the metric
  * tenantId: Tenant to which the metric belongs to
  * userId: User to which this metric is associated with
  * communityId: Community to which this metric is associated with
  * metricTimestamp: Timestamp of the metric
  * metricValue: Metric value
  * rawAccessCount: Raw access count used for the metric value calculation
  * userMean: Mean of user over a period used in community median case
  * communityMedian: Median at community level in case this is a metric related to community
  * rawAccessCountByEventType: Split of raw access count by event type
  */
case class OpsRateMetricDb(id: String,
                           tenantId: String,
                           userId: Option[String],
                           communityId: Option[String],
                           metricTimestamp: Long,
                           metricValue: Double,
                           rawAccessCount: Long,
                           userMean: Option[Double] = None,
                           communityMedian: Option[Double] = None,
                           rawAccessCountByEventType: Option[Map[AuditEventType, Long]] = None
                          )