/*
 * $Id$
 *
 * Copyright (c) 2020 NetApp, Inc.
 * All rights reserved.
 */
package com.netapp.df.uba.server.common.misc.interceptor

import com.netapp.df.uba.server.common.misc.apikey.{ApiKeyCache, TenantApiKeys}
import com.netapp.df.uba.server.common.misc.apikey.service.CSApiKeyCacheService
import com.netapp.df.uba.server.common.misc.log.LogTrait

import scala.util.{Failure, Success, Try}

/**
  * This object holds the singleton of ApiKeyCache object which holds
  * the distributed read through cache of ApiKey
  */
object InterceptorApiCacheService extends LogTrait {

  @volatile private var apiKeyCacheService:Option[CSApiKeyCacheService] = None
  final val publicApiHeaderName = "x-cloudinsights-apikey"

  //Method to initialize ApiCacheService
  def init(): Unit = {
    logger.info(s" Initializing ApiCache Service")
    if (apiKeyCacheService.isEmpty) {
      InterceptorApiCacheService.synchronized {
        if (apiKeyCacheService.isEmpty) {
          ApiKeyCache.getInstance()
          apiKeyCacheService = Some(new CSApiKeyCacheService())
        }
      }
    }
  }

  def getApiKeyCacheService: Option[CSApiKeyCacheService] = apiKeyCacheService

  //Method to retrieve all the publicApi Keys of the tenant
  def getTenantPublicApiKeys(tenantId: String): Try[TenantApiKeys] = {

    try {
      if (apiKeyCacheService.isDefined) {
        val tenantApiKeys = apiKeyCacheService.get.getTenantApiKeys(tenantId)
        Success(tenantApiKeys)
      } else {
        Failure(new Exception("ApiKeyCacheService is not intialized"))
      }
    }
    catch {
      case apikeyCacheServiceException: Exception =>
        Failure(apikeyCacheServiceException)
    }
  }
}
