/*
 * $Id$
 *
 * Copyright (c) 2018 NetApp, Inc.
 * All rights reserved.
 */
package com.netapp.df.uba.server.common.misc.log

import org.slf4j
import org.slf4j.LoggerFactory

import java.io.{PrintWriter, StringWriter}

/**
  * A trait to be used by all classes that need logging to be done
  * but is not an actor.
  */
trait LogTrait {
  lazy val logger: slf4j.Logger = LoggerFactory.getLogger(getClass)

  def logDebugT(tenantId: String, message: String): Unit = {
    if (MdcUtils.getMdcTenantIdContext.isDefined)
      logger.debug(message)
    else
      logger.debug(s"Tenant: $tenantId; $message")
  }

  def logInfoT(tenantId: String, message: String): Unit = {
    if (MdcUtils.getMdcTenantIdContext.isDefined)
      logger.info(message)
    else
      logger.info(s"Tenant: $tenantId; $message")
  }

  def logWarningT(tenantId: String, message: String): Unit = {
    if (MdcUtils.getMdcTenantIdContext.isDefined)
      logger.warn(message)
    else
      logger.warn(s"Tenant: $tenantId; $message")
  }

  def logErrorT(tenantId: String, message: String, exception: Throwable, detail: Boolean = false): Unit = {
    if (null != exception) {
      if (MdcUtils.getMdcTenantIdContext.isDefined)
        logger.error(s"$message. Reason: ${exception.getMessage}")
      else
        logger.error(s"Tenant: $tenantId; $message. Reason: ${exception.getMessage}")

      if (detail) {
        val sw = new StringWriter
        exception.printStackTrace(new PrintWriter(sw))
        if (MdcUtils.getMdcTenantIdContext.isDefined)
          logger.error(s"Detailed Reason: ${sw.toString}")
        else
          logger.error(s"Tenant: $tenantId; Detailed Reason: ${sw.toString}")
      }
    }
  }

  def logErrorT(tenantId: String, message: String): Unit = {
    if (MdcUtils.getMdcTenantIdContext.isDefined)
      logger.error(message)
    else
      logger.error(s"Tenant: $tenantId; $message")
  }

  def logErrorDetail(message: String, exception: Throwable, detail: Boolean = false): Unit = {
    if (null != exception) {
      logger.error(s"$message. Reason: ${exception.getMessage}")
      if (detail) {
        val sw = new StringWriter
        exception.printStackTrace(new PrintWriter(sw))
        logger.error(s" Detailed Reason: ${sw.toString}")
      }
    }

  }
}