/*
 * $Id$
 *
 * Copyright (c) 2021 NetApp, Inc.
 * All rights reserved.
 */

package com.netapp.df.uba.server.common.misc.log

import org.slf4j.MDC

object MdcKeys {
  val TenantId = "tenantId"
  val ElasticClusterId = "elasticClusterId"
}

//Contains the utility methods that set the mdc context keys used in logging
object MdcUtils {

  def setElasticContextForLogging(elasticClusterId: String): Unit = {
    MDC.put(MdcKeys.ElasticClusterId, elasticClusterId)
  }

  def setTenantIdContextForLogging(tenantId: String): Unit = {
    MDC.put(MdcKeys.TenantId, tenantId)
  }

  def getMdcTenantIdContext: Option[String] = {
    Option(MDC.get(MdcKeys.TenantId))
  }

  def getMdcElasticClusterIdContext: Option[String] = {
    Option(MDC.get(MdcKeys.ElasticClusterId))
  }

  def clearContext(): Unit = {
    MDC.clear()
  }
}
