/*
 * $Id$
 *
 * Copyright (c) 2021 NetApp, Inc.
 * All rights reserved.
 */
package com.netapp.df.uba.server.common.misc.model

import com.netapp.df.uba.server.common.misc.dbmodel.ActionType.ActionType
import com.netapp.df.uba.server.common.misc.dbmodel.ExpiryMode.ExpiryMode
import com.netapp.df.uba.server.common.misc.dbmodel.LimitUserAccessMode.LimitUserAccessMode
import com.netapp.df.uba.server.common.misc.dbmodel.UserBlockType.UserBlockType

/**
  * ActionResult is the message received from config for every action i.e limit user access, restore access and create snapshot
  *
  * @param tenantId
  * @param actionId
  * @param actionType
  * @param alertId
  * @param userId
  * @param isAutomatic
  * @param createdBy
  * @param response
  */
case class ActionResult(tenantId: String,
                        actionId: String,
                        actionType: ActionType,
                        alertId: Option[String] = None,
                        userId: Option[String] = None,
                        isAutomatic: Boolean,
                        createdBy: Option[String] = None, // only applicable for manual actions, ie when isAutomatic is false
                        response: Response)

/**
  * Snapshot result is
  *
  * @param datasourceId
  * @param volumeName
  * @param status
  * @param snapshotName
  * @param snapshotTimestamp
  * @param error
  */
case class VolumeSnapshotResult(datasourceId: String,
                                policyId: Option[String] = None,
                                policyName: Option[String] = None,
                                volumeName: String,
                                status: com.netapp.df.uba.server.common.misc.dbmodel.ActionStatus.ActionStatus,
                                snapshotName: Option[String] = None,
                                snapshotTimestamp: Option[Long] = None,
                                error: Option[String] = None)


//UserBlockType -> In Progress will have IP,SID or IpAndSidBased
// Success -> None
// Failure -> None

// sid Success response -> userIps->null, sid, userBlockType->null, limitUserAccessMode, expiryMode,expiryTime,status-> success
// userIps success -> userIps, sid= null, userBlockType=null, mode, expiryMode, expiryTime, status->Success

// sid Failure -> userIps null, sid, userBlockType null, mode, expiry null, duration null status failure , error
// userIp Failure -> userIps , sid null , userBlockType null, mode, expiry null, duration null ,status failure, error

case class UserAccessResult(datasourceId: String,
                            userIps: Option[List[String]],
                            sid: Option[String],
                            userBlockType: Option[UserBlockType],
                            policyId: Option[String] = None,
                            policyName: Option[String] = None,
                            limitUserAccessMode: Option[LimitUserAccessMode] = None,
                            expiryMode: Option[ExpiryMode] = None,
                            expiryTimestamp: Option[Long] = None,
                            duration: Option[Long] = None,
                            status: com.netapp.df.uba.server.common.misc.dbmodel.ActionStatus.ActionStatus,
                            error: Option[String] = None)

case class VolumeSnapshotResponse(volumeSnapshotResult: Option[VolumeSnapshotResult]) extends Response

case class UserAccessResponse(userAccessResult: Option[UserAccessResult]) extends Response

trait Response

/* Sample JSON below

{ // snapshot success
  "actionId": "123456789",
  "alertId": "987654321",
  "createdBy": "sandeep",
  "isAutomatic": true,
  "type": "create_snapshot",
  "response": {
      "volumeSnapshotResult": {
      "datasourceId": "8b34c8f9-246a-48a5-a2e7-e6e00673b426",
      "volumeName": "volume1",
      "status": "Success",
      "snapshotName": "cloudsecure_123456789",
      "snapshotTimestamp": "123456789"
      }
   }
}



{ // snapshot failure
  "actionId": "123456789",
  "alertId": "987654321",
  "createdBy": "sandeep",
  "isAutomatic": true,
  "type": "create_snapshot",
  "response": {
      "volumeSnapshotResult": {
      "datasourceId": "8b34c8f9-246a-48a5-a2e7-e6e00673b426",
      "volumeName": "volume2",
      "status": "Failure",
      "error": "Volume volume2 does not exist in Vserver vs1"
      }
   }
}



*/
