/*
 * $Id$
 *
 * Copyright (c) 2018 NetApp, Inc.
 * All rights reserved.
 */
package com.netapp.df.uba.server.common.misc.model

import com.netapp.df.uba.server.common.misc.model.ErrorCode.ErrorCode

/**
  * Error is the class used to represent an erroneous condition in any of the APIs. It consists of
  * - Error code is one of the pre-defined error codes
  * - A human readable error message
  * - Target of the error
  * - Inner details of the error.
  */
case class Error(code: ErrorCode, message: String, target: String, details: Option[List[Error]] = None) {
  /**
    * Utility method to create a detailed error message when an error object has inner errors.
    * Typically used in topic or index management
    */
  def detailedErrorMessage: String = {
    val mainErrorMessage: String = message

    if (details.isEmpty || details.get.isEmpty) mainErrorMessage
    else {
      val innerErrors = details.get
      val innerErrorMessage = innerErrors
        .map(innerError => s"${innerError.target}: ${innerError.message}")
        .mkString("Details - [", ", ", "]")

      s"$mainErrorMessage $innerErrorMessage"
    }
  }
}