/*
 * $Id$
 *
 * Copyright (c) 2018 NetApp, Inc.
 * All rights reserved.
 */
package com.netapp.df.uba.server.common.misc.model

import akka.actor.NoSerializationVerificationNeeded

// String constants to be used
object StringConstants {
  val InitializingString: String = "initializing"
  val ErrorString: String = "error"
  val RunningString: String = "running"
  val FailedString: String = "failed"
  val NotEnabledString: String = "notEnabled"
  val StoppingString: String = "stopping"
  val StoppedString: String = "stopped"
  val NotApplicableString: String = "notApplicable"
}

// Base trait for all messages related to services
trait Message extends NoSerializationVerificationNeeded

// Base trait for messages that are commands to actors
trait Command extends Message

// Base trait for messages that are events to actors
trait Event extends Message

// A message to send to this actor to check for infrastructure components.
case object CheckInfra extends Command

// Periodic Timer key and initial delay single timer key
case object PeriodicTimerKey
case object SingleTimerKey

// periodic tick message
case object PeriodicTick

// Initial tick message
case object FirstTick

// A trait to indicate the status of an action asked of an actor.
trait ActionStatus extends Event {
  // Context represents the context of the action asked for
  def context: String
}

// Indicates that the asked action for the context succeeded
case class ActionSucceeded(context: String) extends ActionStatus

// Indicates that the asked action for the context failed.
case class ActionFailed(context: String, error: Error) extends ActionStatus