/*
 * $Id$
 *
 * Copyright (c) 2018 NetApp, Inc.
 * All rights reserved.
 */
package com.netapp.df.uba.server.common.misc.model

import com.netapp.df.uba.server.common.misc.model.ErrorCode.ErrorCode
import com.netapp.df.uba.server.common.misc.model.StringConstants._

// Base trait for service related events.
trait ServiceEvent extends Event

// Service State is a type of ServiceEvent
sealed abstract class ServiceStatus extends ServiceEvent {
  def statusString: String
}

case object Initializing extends ServiceStatus {
  override def statusString: String = InitializingString
}

case object Running extends ServiceStatus {
  override def statusString: String = RunningString
}

final case class Failed(reason: String, errorCode: ErrorCode = ErrorCode.InternalError) extends ServiceStatus {
  override def statusString: String = FailedString
}

case object NotEnabled extends ServiceStatus {
  override def statusString: String = NotEnabledString
}

case object Stopping extends ServiceStatus {
  override def statusString: String = StoppingString
}

case object Stopped extends ServiceStatus {
  override def statusString: String = StoppedString
}