/*
 * $Id$
 *
 * Copyright (c) 2018 NetApp, Inc.
 * All rights reserved.
 */
package com.netapp.df.uba.server.common.misc.settings

import com.netapp.df.uba.server.common.misc.utils.SettingUtils
import com.typesafe.config.Config

/**
  * RestServer settings are for micro-services that have a REST server running in them
  */
object RestServerSettings {
  def apply(config: Config): RestServerSettings = RestServerSettings(
    config.getString("host"),
    SettingUtils.validMinIntWithDefault(config, "port", 1024)
  )
}

case class RestServerSettings(httpHost: String, httpPort: Int)

/**
  * Companion object for CommonSettings to load from config object
  */
object CommonSettings {
  val CommonSettingPrefix = "microservice.common"

  def apply(config: Config): CommonSettings = {
    val restServerSettingsOption = if (config.hasPath("http")) Some(RestServerSettings(config.getConfig("http")))
    else None

    CommonSettings(
      config.getString("environment"),
      config.getString("external-base-path"),
      restServerSettingsOption,
      config.getString("locale.language"),
      config.getString("locale.country"),
      config.getString("loglevel")
    )
  }
}

/**
  * CommonSettings contains common settings like
  * environment, http host, http port for API services, locale for resource bundle messages etc.
  */
case class  CommonSettings(environment: String,
                          externalBasePath: String,
                          restServerSettings: Option[RestServerSettings],
                          localeLanguage: String,
                          localeCountry: String,
                          loglevel: String)