/*
 * $Id$
 *
 * Copyright (c) 2020 NetApp, Inc.
 * All rights reserved.
 */
package com.netapp.df.uba.server.common.misc.settings

import com.netapp.df.uba.server.common.misc.dbmodel.AuditEventType
import com.netapp.df.uba.server.common.misc.dbmodel.AuditEventType.AuditEventType
import com.netapp.df.uba.server.common.misc.utils.SettingUtils
import com.typesafe.config.Config

import scala.collection.JavaConverters._
import scala.collection.mutable

/**
  * EventExclusionSettings contains the settings for excluding a set of events based on
  * some configurations. It is used in multiple modules:
  * a. Noise filter in forensic-APIs/UI
  * b. Community detection to exclude a set of events from CD algorithm
  */
object EventExclusionSettings {
  def apply(config: Config): EventExclusionSettings = {
    val eventTypeWithExtensionsList = config.getConfigList("event-type-with-extensions").asScala
    val eventTypeToExtensionsMap = eventTypeWithExtensionsList.foldLeft(mutable.Map[AuditEventType, Set[String]]())((map, config) => {
      val eventType = AuditEventType.withName(config.getString("event-type"))
      val extensions = SettingUtils.getNonEmptyValueStringSet(config, "extensions")
      map.update(eventType, map.getOrElse(eventType, Set.empty)++ extensions)
      map
    }).toMap

    EventExclusionSettings(
    SettingUtils.getNonEmptyValueStringSet(config, "extensions"),
    SettingUtils.getNonEmptyValueStringSet(config, "entity-names"),
    SettingUtils.getNonEmptyValueStringSet(config, "entity-name-prefixes"),
    SettingUtils.getNonEmptyValueStringSet(config, "entity-name-suffixes"),
    eventTypeToExtensionsMap
  )
  }
}

case class EventExclusionSettings(extensionsToExclude: Set[String],
                                  entityNamesToExclude: Set[String],
                                  entityNamePrefixesToExclude: Set[String],
                                  entityNameSuffixesToExclude: Set[String],
                                  eventTypeToExtensionsMap: Map[AuditEventType, Set[String]])