/*
 * $Id$
 *
 * Copyright (c) 2019 NetApp, Inc.
 * All rights reserved.
 */
package com.netapp.df.uba.server.common.misc.settings

import com.netapp.df.uba.server.common.misc.settings.PathConfigMode.PathConfigMode
import com.typesafe.config.Config

/**
  * Enumeration representing how ADR should post the event to auditevents.raw topic.
  * no-change: No change in the way path came from the collector
  * directory: Go up by few levels from the lower level entity path
  * mount-path: mount path which should be data volume
  * equivalent considering only SVM is the data collector currently
  */
object PathConfigMode extends Enumeration {
  type PathConfigMode = Value

  val NoChange: PathConfigMode = Value("no-change")
  val Directory: PathConfigMode = Value("directory")
  val MountPath: PathConfigMode = Value("mount-path")
}

/**
  * EventPathSettings represent the configuration to figure out how the event
  * from the collector needs to be manipulated before inserting it into the pipeline.
  */
object EventPathSettings {
  def apply(config: Config): EventPathSettings = EventPathSettings(
    PathConfigMode.withName(config.getString("mode")),
    config.getInt("directory.exclude.level")
  )
}

case class EventPathSettings(pathConfigMode: PathConfigMode,
                             excludeDirectoryLevel: Int = 1)