/*
 * $Id$
 *
 * Copyright (c) 2018 NetApp, Inc.
 * All rights reserved.
 */
package com.netapp.df.uba.server.common.misc.utils

/**
  * Utility object for enumerations where an unexpected string that does not match any of the enums
  * should return a specific default enum value.
  *
  * Should be used for forward compatibility when ZAPIs from a higher version cluster return a different
  * value for an enum that is not yet added to this codebase.
  */
object EnumerationUtils {
  /**
    * Returns the right enum value for a given string "fromApi" if it is present in the enum's value set.
    * if not, returns the defaultEnum
    */
  def getValidEnumValue[T](values: Set[T], fromApi: String, defaultEnum: T)(strEnumConverter: (String) => T): T =
    if (isValidType[T](values, fromApi)) strEnumConverter(fromApi)
    else defaultEnum

  /**
    * Checks if the value from the external API result "fromApi" is available in the Enum value set
    */
  def isValidType[T](values: Set[T], fromApi: String): Boolean = values.exists(_.toString == fromApi)
}