/*
 * $Id$
 *
 * Copyright (c) 2018 NetApp, Inc.
 * All rights reserved.
 */
package com.netapp.df.uba.server.common.misc.utils

import java.security.{MessageDigest, NoSuchAlgorithmException}

/**
  * A set of utilities for hex and hashing used when storing data in elasticsearch
  */
object HexHashUtils {

  final val MessageDigestAlgorithm = "SHA-256"
  /**
    * A utility method to convert an array of bytes to hex string
    */
  def hexValueOf(buffer: Array[Byte]): String = buffer.map("%02X" format _).mkString

  /**
    * A utility method to get SHA-256 based message digest of the given set of bytes
    */
  def sha256(buffer: Array[Byte]): Array[Byte] = try {
    MessageDigest.getInstance(MessageDigestAlgorithm)
      .digest(buffer)
  } catch {
    case _: NoSuchAlgorithmException =>
      throw new RuntimeException(s"Failed to find the algorithm for message digest: $MessageDigestAlgorithm")
  }

  /**
    * A utility method to get a SHA-256 message digest hex string given a set of byets
    */
  def sha256Hex(buffer: Array[Byte]): String = hexValueOf(sha256(buffer))


  /**
    * A utility method to get a SHA-256 message digest hex string given a string
    */
  def sha256Hex(input: String): String = sha256Hex(input.getBytes)
}