/*
 * $Id$
 *
 * Copyright (c) 2018 NetApp, Inc.
 * All rights reserved.
 */
package com.netapp.df.uba.server.common.misc.utils

import java.text.MessageFormat
import java.util.ResourceBundle

/**
  * Utility object for
  * - Obtaining a message of the given key from the given resource bundle
  * - Formatting the message with the given set of message arguments
  */
object RbUtils {
  final val RBKEY_API_JWT_TOKEN_INVALID = "api.invalid_jwt_token"
  final val RBKEY_API_USER_NOT_AUTHORIZED = "api.unauthorized_user"

  /*
   Defensive way to obtain the error message.
   Do not throw to upper layers issues in getting the message for a specific key or
   if formatting the message with the given arguments fails.
    */
  def rbMessage(resourceBundle: ResourceBundle, messageKey: String, messageArgs: String*): String = {

    if (resourceBundle.containsKey(messageKey)) {
      val messageString = resourceBundle.getString(messageKey)
      try {
        MessageFormat.format(messageString, messageArgs: _*)
      } catch {
        case ex: Exception => s"Failed to format message $messageString for key $messageKey. Reason: ${ex.getMessage}"
      }
    }
    else s"Missing $messageKey in resource bundle."
  }
}
