/*
 * $Id$
 *
 * Copyright (c) 2022 NetApp, Inc.
 * All rights reserved.
 */
package com.netapp.df.uba.server.common.pipeline.job

import akka.actor.{Actor, ActorSystem, ExtendedActorSystem, Extension, ExtensionId, ExtensionIdProvider}
import com.netapp.df.uba.server.common.misc.settings.CommonSettings._
import com.netapp.df.uba.server.common.misc.utils.RbUtils
import com.typesafe.config.Config

import java.util.{Locale, ResourceBundle}

object PipelineJobManagerRbKeys {
  // API related errors
  final val RBKEY_API_INTERNAL_ERROR_TIMEOUT = "api.internal_error_timeout"
  final val RBKEY_API_INTERNAL_ERROR = "api.internal_error"
  final val RBKEY_API_INTERNAL_ERROR_REASON = "api.internal_error_with_reason"
  final val RBKEY_API_VALIDATION_ERROR = "api.validation_error"
  final val RBKEY_API_METHOD_NOT_SUPPORTED_ERROR = "api.method_not_supported_error"
  final val RBKEY_API_ROUTE_NOT_FOUND_ERROR = "api.route_not_found_error"

  final val RBKEY_API_SERVICE_NOT_RUNNING = "api.service_not_running"
  final val RBKEY_API_SERVICE_DISABLED = "api.service_disabled"
  final val RBKEY_API_SERVICE_FAILED = "api.service_failed"

  // Common connection related failures
  final val RBKEY_SCHEMA_REGISTRY_URL_FAILURE = "micro-service.schema_registry_url_failure"
  final val RBKEY_KAFKA_CONNECTION_FAILURE = "micro-service.kafka_failure"
}

class PipelineJobManagerResBundleImpl(config: Config) extends Extension {

  private val locale = new Locale(
    config.getString(s"$CommonSettingPrefix.locale.language"),
    config.getString(s"$CommonSettingPrefix.locale.country"))

  // Resource bundle is loaded with the locale as given in the settings.
  val resourceBundle: ResourceBundle = ResourceBundle.getBundle("ExtMessageBundlePipe", locale)

  // Defensive way to obtain the error message.
  def rbMessage(messageKey: String, messageArgs: String*): String = RbUtils.rbMessage(resourceBundle, messageKey, messageArgs: _*)
}

object PipelineJobManagerResBundle extends ExtensionId[PipelineJobManagerResBundleImpl] with ExtensionIdProvider {

  override def lookup: PipelineJobManagerResBundle.type = PipelineJobManagerResBundle

  override def createExtension(system: ExtendedActorSystem) =
    new PipelineJobManagerResBundleImpl(system.settings.config)

  // Retrieve the settings extension for the given system
  override def get(system: ActorSystem): PipelineJobManagerResBundleImpl = super.get(system)
}

/**
  * A trait to indicate that the actor needs messages from resource bundle in resources folder
  */
trait PipelineJobManagerResourceBundleUser extends Actor {
  // Define a way to get into RbExtension
  protected val resBundleExt = PipelineJobManagerResBundle(context.system)

  // A way to get the resource bundle. Useful when messages are printed from helper classes which are not actors.
  protected val resourceBundle: ResourceBundle = resBundleExt.resourceBundle

  // Helper method to get the formatted message from resource bundle after filling in the arguments.
  def rbMessage(messageKey: String, messageArgs: String*): String = resBundleExt.rbMessage(messageKey, messageArgs: _*)
}