/*
 * $Id$
 *
 * Copyright (c) 2022 NetApp, Inc.
 * All rights reserved.
 */
package com.netapp.df.uba.server.common.pipeline.job

import com.netapp.df.uba.server.common.flink.settings.{FlinkJobStateControlSettings, FlinkSettings}
import com.netapp.df.uba.server.common.kafka.KafkaSettings
import com.netapp.df.uba.server.common.misc.utils.SettingUtils
import com.typesafe.config.Config

/**
  * Companion object for PipelineJobManagerSettings to load from config object
  */
object PipelineJobManagerSettings {

  private final val KafkaConfigPrefix = "kafka.config"
  private final val FlinkConfigPrefix = "flink.config"
  private final val FlinkJobStateControlPrefix = "job.state.control"

  def apply(config: Config,
            publishingTopics: List[String] = Nil,
            subscribingTopics: List[String] = Nil,
            infoTopics: List[String] = Nil,
            flinkJobKeys: List[String] = Nil): PipelineJobManagerSettings = {

    val pipelinesServiceUrl = SettingUtils.mandatoryConfigValue(config, "service.pipelines.url")
    val vaultServiceName = SettingUtils.mandatoryConfigValue(config, "vault.service.name")
    val tenantsServiceUrl = SettingUtils.mandatoryConfigValue(config, "service.tenants.url")
    val dbsServiceUrl = SettingUtils.configValueWithEmptyOrMissingAsNone(config, s"service.dbs.url")
    val serviceConfigMgmtUrl = SettingUtils.mandatoryConfigValue(config, "service.config.mgmt.url")

    val kafkaSettings = KafkaSettings(
      config.getConfig(KafkaConfigPrefix),
      publishingTopics,
      subscribingTopics,
      infoTopics
    )
    val flinkSettings = FlinkSettings(config.getConfig(FlinkConfigPrefix), flinkJobKeys)
    val flinkJobStateControlSettings = FlinkJobStateControlSettings(config.getConfig(FlinkJobStateControlPrefix))

    PipelineJobManagerSettings(
      kafkaSettings,
      flinkSettings,
      flinkJobStateControlSettings,
      pipelinesServiceUrl,
      vaultServiceName,
      tenantsServiceUrl,
      serviceConfigMgmtUrl,
      dbsServiceUrl
    )
  }
}

/**
  * PipelineJobManagerSettings contains kafka settings, flink settings etc
  */
case class PipelineJobManagerSettings(kafkaSettings: KafkaSettings,
                                      flinkSettings: FlinkSettings,
                                      jobControlSettings: FlinkJobStateControlSettings,
                                      servicePipelinesUrl: String,
                                      vaultServiceName: String,
                                      serviceTenantsUrl:String,
                                      serviceConfigMgmtUrl: String,
                                      serviceDbsUrl: Option[String])